@@ -1,11 +1,12 @@
 package Net::Async::Redis::Cluster::Node::XS;
 
+use Object::Pad;
+class Net::Async::Redis::Cluster::Node::XS :isa(Net::Async::Redis::Cluster::Node);
+
 use strict;
 use warnings;
 
-our $VERSION = '0.014'; # VERSION
-
-use parent qw(Net::Async::Redis::Cluster::Node);
+our $VERSION = '1.000'; # VERSION
 
 =head1 NAME
 
@@ -24,9 +25,7 @@ for instructions.
 use Net::Async::Redis::XS;
 use Future::AsyncAwait;
 
-async sub establish_primary_connection {
-    my ($self) = @_;
-
+async method establish_primary_connection {
     $self->add_child(
         my $redis = Net::Async::Redis::XS->new(
             $self->Net::Async::Redis::Cluster::node_config,
